#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
SAT: a jabber client
Copyright (C) 2009, 2010  Jérôme Poisson (goffi@goffi.org)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from logging import debug, info, error
from xml.dom import minidom
from wokkel import data_form
import pdb

class XMLTools:
    """This class help manage XML used in SàT (parameters, registration, etc) """

    
    @staticmethod
    def dataForm2xml(form):
        """Take a data form (xep-0004, Wokkel's implementation) and convert it to a SàT xml"""
        
        impl = minidom.getDOMImplementation()

        doc = impl.createDocument(None, "form", None)
        top_element = doc.documentElement
        
        #result_xml = ["<form>", "</form>"]
        if form.instructions:
            elem = doc.createElement('elem')
            elem.setAttribute('name','instructions')
            elem.setAttribute('type','text')
            text = doc.createTextNode('\n'.join(form.instructions))
            elem.appendChild(text)
            top_element.appendChild(elem)
        for field in form.fieldList:
            if field.fieldType == 'text-single':
                __field_type = "string"
            elif field.fieldType == 'text-private':
                __field_type = "password"
            else:
                error (u"FIXME FIXME FIXME: Type [%s] is not managed yet by SàT" % field.fieldType)
                __field_type = "string"
            
            elem = doc.createElement('elem')
            elem.setAttribute('name', field.var)
            elem.setAttribute('type', __field_type)
            elem.setAttribute('label', field.label or "")
            if field.value:
                text = doc.createTextNode(field.value)
                elem.appendChild(text)
            top_element.appendChild(elem)
        result = doc.toxml()
        doc.unlink()
        return result

    @staticmethod
    def tupleList2dataForm(values):
        """convert a list of tuples (name,value) to a wokkel submit data form"""
        form = data_form.Form('submit')
        for value in values:
            field = data_form.Field(var=value[0], value=value[1])
            form.addField(field)

        return form
            
    

